pub(crate) mod allocator;
pub use allocator::fill_alignment_gap;
pub use allocator::AllocationError;
pub use allocator::Allocator;

pub(crate) mod allocators;
pub use allocators::AllocatorSelector;

mod bumpallocator;
pub use bumpallocator::BumpAllocator;

mod large_object_allocator;
pub use large_object_allocator::LargeObjectAllocator;

mod malloc_allocator;
pub use malloc_allocator::MallocAllocator;

pub mod immix_allocator;
pub use self::immix_allocator::ImmixAllocator;

mod markcompact_allocator;
pub use markcompact_allocator::MarkCompactAllocator;

pub(crate) mod embedded_meta_data;
